<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet version='1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform' xmlns:table="urn:oasis:names:tc:opendocument:xmlns:table:1.0" xmlns:text="urn:oasis:names:tc:opendocument:xmlns:text:1.0" xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0" xmlns:xlink="http://www.w3.org/1999/xlink">


    <xsl:template match="s[@type='em']">
        <text:span text:style-name="Bdf_20_Txt_20_Em"><xsl:value-of select="."/></text:span>
    </xsl:template>

    <xsl:template match="s[@type='emstrg']">
        <text:span text:style-name="Bdf_20_Txt_20_Emt_20_Strg"><xsl:value-of select="."/></text:span>
    </xsl:template>

    <xsl:template match="s[@type='strg']">
        <text:span text:style-name="Bdf_20_Txt_20_Strg"><xsl:value-of select="."/></text:span>
    </xsl:template>

    <xsl:template match="s[@type='link']">
        <text:a xlink:type="simple" xlink:href="{@ref}"><text:span text:style-name="Bdf_20_Txt_20_Link"><xsl:value-of select="."/></text:span></text:a>
    </xsl:template>

    <xsl:template match="s[@type='iref']">
        <text:a xlink:type="simple" xlink:href="#{@ref}"><text:span text:style-name="Bdf_20_Txt_20_Iref"><xsl:value-of select="."/></text:span></text:a>
    </xsl:template>

    <xsl:template match="s[@type='anchor']">
        <xsl:choose>
            <xsl:when test="string-length(.) &gt; 0">
                <text:bookmark-start text:name="{@ref}"/>
                <text:span text:style-name="Bdf_20_Txt_20_Anchor"><xsl:value-of select="."/></text:span>
                <text:bookmark-end text:name="{@ref}"/>
            </xsl:when>
            <xsl:otherwise><text:bookmark text:name=""/></xsl:otherwise>
        </xsl:choose>

    </xsl:template>

    <xsl:template match="s[@type='cite']">
        <xsl:call-template name="SpanA">
            <xsl:with-param name="Class" select="'Cite'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="s[@type='dfn']">
        <xsl:call-template name="SpanA">
            <xsl:with-param name="Class" select="'Dfn'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="s[@type='samp']">
        <xsl:call-template name="SpanSubtype">
            <xsl:with-param name="Class" select="'Samp'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="s[@type='kbd']">
        <xsl:call-template name="SpanSubtype">
            <xsl:with-param name="Class" select="'Kbd'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="s[@type='code']">
        <xsl:call-template name="SpanSubtype">
            <xsl:with-param name="Class" select="'Code'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="s[@type='var']">
        <xsl:call-template name="SpanSubtype">
            <xsl:with-param name="Class" select="'Var'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="SpanA">
        <xsl:param name="Class"/>
        <xsl:choose>
            <xsl:when test="@ref = true()">
                <text:a xlink:type="simple" xlink:href="{@ref}"><text:span text:style-name="Bdf_20_Txt_20_{$Class}_20_A"><xsl:value-of select="."/></text:span></text:a>
            </xsl:when>
            <xsl:otherwise>
                <text:span text:style-name="Bdf_20_Txt_20_{$Class}"><xsl:value-of select="."/></text:span>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="SpanSubtype">
        <xsl:param name="Class"/>
        <text:span text:style-name="Bdf_20_Txt_20_{$Class}"><xsl:value-of select="."/></text:span>
    </xsl:template>


    <xsl:template match="p">
        <xsl:apply-templates select="." mode="submode_PCLASS">
            <xsl:with-param name="param_Class" select="'Bdf_20_Txt'"/>
        </xsl:apply-templates>
    </xsl:template>

    <xsl:template match="p[@type='question']">
        <xsl:apply-templates select="." mode="submode_PCLASS">
            <xsl:with-param name="param_Class" select="'Bdf_20_Txt_20_Question'"/>
        </xsl:apply-templates>
    </xsl:template>

    <xsl:template match="p[@type='remarque']">
        <xsl:apply-templates select="." mode="submode_PCLASS">
            <xsl:with-param name="param_Class" select="'Bdf_20_Txt_20_Remarque'"/>
        </xsl:apply-templates>
    </xsl:template>

    <xsl:template match="p[@type='note']">
        <xsl:apply-templates select="." mode="submode_PCLASS">
            <xsl:with-param name="param_Class" select="'Bdf_20_Txt_20_Note'"/>
        </xsl:apply-templates>
    </xsl:template>

    <xsl:template match="p" mode="submode_LI">
        <xsl:apply-templates select="." mode="submode_PCLASS">
            <xsl:with-param name="param_Class" select="'Bdf_20_Txt_20_Li'"/>
        </xsl:apply-templates>
    </xsl:template>

    <xsl:template match="p[@type='citation']">
        <text:p text:style-name="Bdf_20_Txt_20_Citation"><xsl:call-template name="subtemplate_PRGCONTENT"/></text:p>

        <xsl:apply-templates select="following-sibling::*[1][@type='citation' and @source=false()]" mode="submode_NEXTCITATION"/>

        <xsl:if test="string-length(@source) &gt;0">
            <text:p text:style-name="Bdf_20_Txt_20_Citation_20_Source">
                <xsl:value-of select="@source"/>
            </text:p>
        </xsl:if>
    </xsl:template>

    <xsl:template match="p[@type='citation' and @source=false() and preceding-sibling::*[1]/@type='citation']">
    </xsl:template>

    <xsl:template match="p" mode="submode_NEXTCITATION">
        <text:p text:style-name="Bdf_20_Txt_20_Citation"><xsl:call-template name="subtemplate_PRGCONTENT"/></text:p>
        <xsl:apply-templates select="following-sibling::*[1][@type='citation' and @source=false()]" mode="submode_NEXTCITATION"/>
    </xsl:template>


    <xsl:template match="p" mode="submode_PCLASS">
        <xsl:param name="param_Class"/>
        <text:p text:style-name="{$param_Class}">
            <xsl:if test="string-length(@source) &gt;0">
                <text:span text:style-name="Bdf_20_Txt_20_Source">
                    <xsl:value-of select="@source"/>
                    <xsl:text> : </xsl:text>
                </text:span>
            </xsl:if>
            <xsl:call-template name="subtemplate_PRGCONTENT"/>
        </text:p>
    </xsl:template>


    <xsl:template match="h">
        <xsl:variable name="var_Level" select="number(@level) + 2"/>
        <xsl:choose>
            <xsl:when test="$var_Level &lt; 11">
                <text:h text:outline-level="{$var_Level}" text:style-name="Heading_20_{$var_Level}">
                    <xsl:call-template name="subtemplate_PRGCONTENT"/>
                </text:h>
            </xsl:when>
            <xsl:otherwise>
                <text:p text:style-name="Bdf_20_Txt">
                    <xsl:call-template name="subtemplate_PRGCONTENT"/>
                </text:p>
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>

    <xsl:template match="ul">
        <xsl:param name="param_DEPTH" select="1"/>
        <xsl:variable name="StyleName">
            <xsl:text>Bdf_20_Lst_20_</xsl:text>
            <xsl:choose>
                <xsl:when test="starts-with(@class,'OL')">Ol</xsl:when>
                <xsl:otherwise>Ul</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <text:list text:style-name="{$StyleName}">
            <xsl:apply-templates select='li'>
                <xsl:with-param name="param_DEPTH" select="$param_DEPTH + 1"/>
            </xsl:apply-templates>
        </text:list>
    </xsl:template>

    <xsl:template match="ul" mode="submode_LI">
        <xsl:apply-templates select="."/>
    </xsl:template>


    <xsl:template match="li">
        <xsl:param name="param_DEPTH" select="2"/>
        <text:list-item>
            <xsl:for-each select='*'>
                <xsl:apply-templates select='.' mode="submode_LI">
                    <xsl:with-param name="param_DEPTH" select="$param_DEPTH"/>
                </xsl:apply-templates>
            </xsl:for-each>
        </text:list-item>
    </xsl:template>

    <xsl:template match="table">
        <xsl:variable name="var_Caption" select="numero = true() or legende = true()"/>
        <xsl:variable name="var_Style">Bdf_20_Table<xsl:if test="$var_Caption = false()">_20_Sans</xsl:if></xsl:variable>
        <xsl:if test="tr">
            <table:table table:name="Tableau{generate-id(.)}" table:style-name="{$var_Style}">
                <table:table-column table:number-columns-repeated="{count(tr[1]/td)}"/>
                <xsl:apply-templates select="tr"/>
            </table:table>
        </xsl:if>
        <xsl:if test="$var_Caption">
            <xsl:call-template name="subtemplate_CAPTION"/>
        </xsl:if>
    </xsl:template>

    <xsl:template match="tr">
        <table:table-row table:style-name="Bdf_20_Table_20_Row">
            <xsl:apply-templates select="*"/>
        </table:table-row>
    </xsl:template>

    <xsl:template match="td">
        <xsl:variable name="PStyle">Bdf_20_Table_20_<xsl:choose><xsl:when test="@type='number'">Number</xsl:when><xsl:when test="@type='header'">Header</xsl:when><xsl:otherwise>String</xsl:otherwise></xsl:choose></xsl:variable>
        <!--
<xsl:if test="@colspan = true()"><xsl:attribute name="colspan"><xsl:value-of select="@colspan"/></xsl:attribute></xsl:if>
            <xsl:if test="@rowspan = true()"><xsl:attribute name="rowspan"><xsl:value-of select="@rowspan"/></xsl:attribute></xsl:if>
            -->
        <table:table-cell table:style-name="Bdf_20_Table_20_Cell" office:value-type="string">
            <text:p text:style-name="{$PStyle}"><xsl:call-template name="subtemplate_PRGCONTENT"/></text:p>
        </table:table-cell>
    </xsl:template>

    <xsl:template match="ln">
        <xsl:param name="param_Caption" select="false()"/>
        <xsl:variable name="PStyle">
            <xsl:text>Bdf_20_Ln</xsl:text>
            <xsl:choose>
                <xsl:when test="position() = 1">_20_1</xsl:when>
                <xsl:when test="($param_Caption = false()) and (position() = last())">_20_L</xsl:when>
            </xsl:choose>
        </xsl:variable>
        <text:p text:style-name="{$PStyle}"><xsl:if test="@indent &gt;0"><xsl:call-template name="subtemplate_INDENT">
                    <xsl:with-param name="param_CHAINE">&#xA0;&#xA0;&#xA0;</xsl:with-param>
                    <xsl:with-param name="param_NOMBRE" select="@indent"/>
                </xsl:call-template>
            </xsl:if>
        <xsl:value-of select="."/></text:p>
    </xsl:template>

    <xsl:template match="div">
        <xsl:variable name="var_Caption" select="numero = true() or legende = true()"/>
        <xsl:apply-templates select="fbl/p" mode="submode_DIV">
            <xsl:with-param name="param_Caption" select="$var_Caption"/>
        </xsl:apply-templates>
        <xsl:if test="$var_Caption">
            <xsl:call-template name="subtemplate_CAPTION"/>
        </xsl:if>
    </xsl:template>

    <xsl:template match="cdatadiv">
        <xsl:variable name="var_Caption" select="numero = true() or legende = true()"/>
        <xsl:if test="$var_Caption">
            <xsl:call-template name="subtemplate_CAPTION"/>
        </xsl:if>
    </xsl:template>

    <xsl:template match="p" mode="submode_DIV">
        <xsl:param name="param_Caption" select="false()"/>
        <xsl:variable name="PStyle">
            <xsl:text>Bdf_20_Txt_20_Div</xsl:text>
            <xsl:choose>
                <xsl:when test="position() = 1">_20_1</xsl:when>
                <xsl:when test="($param_Caption = false()) and (position() = last())">_20_L</xsl:when>
            </xsl:choose>
        </xsl:variable>
        <text:p text:style-name="{$PStyle}"><xsl:call-template name="subtemplate_PRGCONTENT"/></text:p>
    </xsl:template>

    <xsl:template match="code">
        <xsl:variable name="var_Caption" select="numero = true() or legende = true()"/>
        <xsl:apply-templates select="ln">
            <xsl:with-param name="param_Caption" select="$var_Caption"/>
        </xsl:apply-templates>
        <xsl:if test="$var_Caption">
            <xsl:call-template name="subtemplate_CAPTION"/>
        </xsl:if>
    </xsl:template>

    <xsl:template name="subtemplate_CAPTION">
        <text:p text:style-name="Bdf_20_Cpt">
            <xsl:apply-templates select="numero"/>
            <xsl:apply-templates select="legende"/>
        </text:p>
    </xsl:template>

    <xsl:template match="numero">
        <text:span text:style-name="Bdf_20_Cpt_20_Numero">
            <xsl:call-template name="subtemplate_PRGCONTENT"/>
            <xsl:if test="count(../legende) &gt; 0"><xsl:text> : </xsl:text></xsl:if>
        </text:span>
    </xsl:template>

    <xsl:template match="legende">
        <text:span text:style-name="Bdf_20_Cpt_20_Legende">
            <xsl:call-template name="subtemplate_PRGCONTENT"/>
        </text:span>
    </xsl:template>


    <xsl:template name="subtemplate_PRGCONTENT">
        <xsl:if test='(count(*) = 0) and (string-length(.) =0)'><xsl:text>&#x00A0;</xsl:text></xsl:if>
        <xsl:for-each select="node()">
            <xsl:apply-templates select="." />
        </xsl:for-each>
    </xsl:template>

    <xsl:template name="subtemplate_INDENT">
        <xsl:param name="param_CHAINE"/>
        <xsl:param name="param_NOMBRE" select="1"/>
        <xsl:choose>
            <xsl:when test="not($param_NOMBRE) or not($param_CHAINE)"/>
            <xsl:when test="$param_NOMBRE = 1">
                <xsl:value-of select="$param_CHAINE"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test="$param_NOMBRE mod 2"><xsl:value-of select="$param_CHAINE"/></xsl:if>
                <xsl:call-template name="subtemplate_INDENT">
                    <xsl:with-param name="param_CHAINE" select="concat($param_CHAINE,$param_CHAINE)"/>
                    <xsl:with-param name="param_NOMBRE" select="floor($param_NOMBRE div 2)"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="insert">
        <xsl:variable name="var_Caption" select="numero = true() or legende = true()"/>
        <xsl:if test="$var_Caption">
            <xsl:call-template name="subtemplate_CAPTION"/>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>


